<?php
//$Id$

/**
 * @file
 */


/**
 * The default fancybox settings page.
 */
function fancybox_admin_settings($form_state, $presetID = NULL) {
  $key = _fancybox_settings_key($presetID);
  $settings = fancybox_settings($presetID);

  $elements = fancybox_settings_elements_1_2();
  $form = array();
  $form[$key] = array(
    '#tree' => TRUE,
  );

  foreach ($elements as $element_key => $element) {
    $form[$key][$element_key] = $element;
    $form[$key][$element_key]['#default_value'] = $settings[$element_key];
  }
  if ($presetID) {
    $form[$key]['drupalTargetClass'] = array(
      '#title' => t('Restrict FancyBox to images with these classes'),
      '#type' => 'textfield',
      '#default_value' => $settings['drupalTargetClass'],
      '#description' => t('Separate classes with a space or comma and do not include the leading dot.'),
    );
    $options = array('0' => t('Original image'));
    foreach (imagecache_presets() as $preset) {
      $options[$preset['presetid']] = $preset['presetname'];
    }
    $form[$key]['drupalTargetPresetId'] = array(
      '#type' => 'select',
      '#title' => t('Popup ImageCache preset'),
      '#description' => t('Select what ImageCache preset you want the popup image to display as.'),
      '#options' => $options(),
      '#default_value' => $settings['drupalTargetPresetId'],
    );
  }
  else {
    $form[$key]['drupalTargetClass'] = array(
      '#title' => t('Apply FancyBox to links with these classes'),
      '#type' => 'textfield',
      '#default_value' => $settings['drupalTargetClass'],
      '#description' => t('Separate classes with a space or comma and do not include the leading dot.'),
    );
  }
  return system_settings_form($form);
}

/**
 * Helper form element validator : integer >= '#min_value'.
 */
function fancybox_integer_validate($element, &$form_state) {
  $value = $element['#value'];
  if ($value === '') {
    form_set_value($element, 0, $form_state);
  }
  else {
    $min = isset($element['#min_value']) ? $element['#min_value'] : 0;
    if (!is_numeric($value) || intval($value) != $value || $value < $min) {
      form_error($element, t('%name must be an integer greater than or equal to !int.', array('%name' => $element['#title'], '!int' => $min)));
    }
  }
}

/**
 * Helper form element validator : integer > 0.
 */
function fancybox_javascript_function_validate($element, &$form_state) {
  $value = $element['#value'];
  if (empty($value)) {
    form_set_value($element, NULL, $form_state);
  }
  elseif (!preg_match('!^[a-z_]+$!', $value)) {
    form_error($element, t('%name must contain only letters and underscores.', array('%name' => $element['#title'])));
  }
}

function fancybox_settings_elements_1_2() {
  $onoff = array(
    '#type' => 'checkbox',
  );
  $natural_integer = array(
    '#type' => 'textfield',
    '#element_validate' => array('fancybox_integer_validate'),
    '#min_value' => 0,
  );
  $easing = array(
    '#type' => 'select',
    '#description' => t('This changes the animation effect.'),
    '#options' => fancybox_easing_options(),
  );
  $jsfunction = array(
    '#type' => 'textfield',
    '#element_validate' => array('fancybox_javascript_function_validate'),
  );
  return array(
    'drupalEnabled' => $onoff + array('#title' => t('Enabled')),
    'padding' => array(
      '#title' => t('Padding'),
       '#type' => 'textfield',
       '#element_validate' => array('fancybox_integer_validate'),
     ),
    // CUSTOM MODIFICATIONS - Accepts a function too now.
    'title' => $jsfunction + array(
       '#title' => t('Title function callback'),
       '#description' => t('If preset, this function will be called to generate the title caption.'),
     ),
    'imageScale'    => $onoff + array('#title' => t('Image scale')),

    'zoomOpacity'    => $onoff + array('#title' => t('Zoom Opacity')),
    'zoomSpeedIn'     => $natural_integer + array('#title' => t('Zoom speed in')),
    'zoomSpeedOut'     => $natural_integer + array('#title' => t('Zoom speed out')),
    'zoomSpeedChange'     => $natural_integer + array('#title' => t('Zoom speed change')),

    'easingIn'       => $easing + array('#title' => t('Easing in animation')),
    'easingOut'       => $easing + array('#title' => t('Easing out animation')),
    'easingChange'       => $easing + array('#title' => t('Easing change animation')),

    'frameWidth'     => $natural_integer + array('#title' => t('Width')),
    'frameHeight'     => $natural_integer + array('#title' => t('Height')),

    'overlayShow'    => $onoff + array('#title' => t('Use overlay')),

    'overlayOpacity'    => array(
       '#type' => 'select',
       '#title' => t('Overlay opacity'),
       '#options' => drupal_map_assoc(array('0', '0.1', '0.2', '0.3', '0.4', '0.5', '0.6', '0.7', '0.8', '0.9', '1')),
     ),

    'centerOnScroll'    => $onoff + array('#title' => t('centerOnScroll')),
    'hideOnContentClick'    => $onoff + array('#title' => t('Hide on content click')),

//    'itemArray'    => '[]',

    'callbackOnStart'       => $jsfunction + array('#title' => t('Callback on start')),
    'callbackOnShow'      => $jsfunction + array('#title' => t('Callback on show')),
    'callbackOnClose'      => $jsfunction + array('#title' => t('Callback on close')),
  );
}

function fancybox_settings_elements_1_3() {
  return array(
    'padding'       => 10,
    'margin'        => 20,
    'opacity'       => false,
    'modal'       => false,
    'cyclic'        => false,
    'scrolling'     => 'auto', // 'auto', 'yes' or 'no'

    'width'       => 560,
    'height'        => 340,

    'autoScale'     => true,
    'autoDimensions'    => true,
    'centerOnScroll'    => false,

    'ajax'        => array(), //{}
    'swf'         => array(
      'wmode' => 'transparent'
    ),//{ wmode: 'transparent' },

    'hideOnOverlayClick'  => true,
    'hideOnContentClick'  => false,

    'overlayShow'     => true,
    'overlayOpacity'    => 0.3,
    'overlayColor'    => '#666',

    'titleShow'     => true,
    'titlePosition'   => 'outside',  // 'outside', 'inside' or 'over'
    'titleFormat'     => null,

    'transitionIn'    => 'fade', // 'elastic', 'fade' or 'none'
    'transitionOut'   => 'fade', // 'elastic', 'fade' or 'none'

    'speedIn'       => 300,
    'speedOut'      => 300,

    'changeSpeed'     => 300,
    'changeFade'      => 'fast',

    'easingIn'      => 'swing',
    'easingOut'     => 'swing',

    'showCloseButton'   => true,
    'showNavArrows'   => true,
    'enableEscapeButton'  => true,

    'onStart'       => null,
    'onCancel'      => null,
    'onComplete'      => null,
    'onCleanup'     => null,
    'onClosed'      => null
  );
}

function fancybox_easing_options() {
  return array(
    'swing' => 'Default',
    'jswing' => 'jswing',
    'easeInQuad' => 'easeInQuad',
    'easeOutQuad' => 'easeOutQuad',
    'easeInOutQuad' => 'easeInOutQuad',
    'easeInCubic' => 'easeInCubic',
    'easeOutCubic' => 'easeOutCubic',
    'easeInOutCubic' => 'easeInOutCubic',
    'easeInQuart' => 'easeInQuart',
    'easeOutQuart' => 'easeOutQuart',
    'easeInOutQuart' => 'easeInOutQuart',
    'easeInQuint' => 'easeInQuint',
    'easeOutQuint' => 'easeOutQuint',
    'easeInOutQuint' => 'easeInOutQuint',
    'easeInSine' => 'easeInSine',
    'easeOutSine' => 'easeOutSine',
    'easeInOutSine' => 'easeInOutSine',
    'easeInExpo' => 'easeInExpo',
    'easeOutExpo' => 'easeOutExpo',
    'easeInOutExpo' => 'easeInOutExpo',
    'easeInCirc' => 'easeInCirc',
    'easeOutCirc' => 'easeOutCirc',
    'easeInOutCirc' => 'easeInOutCirc',
    'easeInElastic' => 'easeInElastic',
    'easeOutElastic' => 'easeOutElastic',
    'easeInOutElastic' => 'easeInOutElastic',
    'easeInBack' => 'easeInBack',
    'easeOutBack' => 'easeOutBack',
    'easeInOutBack' => 'easeInOutBack',
    'easeInBounce' => 'easeInBounce',
    'easeOutBounce' => 'easeOutBounce',
    'easeInOutBounce' => 'easeInOutBounce',
 );
}
